@@ -13,4 +13,10 @@ def get_bids(x: dict) -> list[tuple[float, float]]:
     return x['bids']
 
 def get_asks(x: dict) -> list[tuple[float, float]]:
-    return x['asks']
\ No newline at end of file
+    return x['asks']
+
+def top_bid_price(x: dict) -> Decimal:
+    return get_price_from_tuple(get_bids(x)[0])
+
+def lowest_ask_price(x: dict) -> Decimal:
+    return get_price_from_tuple(get_asks(x)[0])
\ No newline at end of file
